import { ChangeEventHandler, MouseEventHandler, useState } from "react";
import { useNavigate } from "react-router-dom";

const extractVideoIDFromURL = (input: string): string | null => {
  const { searchParams } = new URL(input);
  return searchParams.get("v");
};

function HomePage(): JSX.Element {
  const [input, setInput] = useState<string>("");
  const [error, setError] = useState<string | null>(null);
  const navigate = useNavigate();

  const handleChange: ChangeEventHandler<HTMLInputElement> = (event) => {
    setInput(event.target.value);
  };

  const handleSubmit: MouseEventHandler<HTMLButtonElement> = () => {
    try {
      const videoId = extractVideoIDFromURL(input);
      if (videoId === null) {
        setError("URL not valid, please enter a valid YouTube URL");
      } else {
        navigate(`/video/${videoId}`);
      }
    } catch (err) {
      setError("URL not valid, please enter a valid YouTube URL");
    }
  };

  return (
    <div>
      <input value={input} onChange={handleChange} />
      <button onClick={handleSubmit}>Submit</button>
      {Boolean(error) && <div>{error}</div>}
    </div>
  );
}

export default HomePage;
